@@ -6,7 +6,7 @@ PATCH_SED_CMD="s/lib${LIBNAME}/lib${VENDOR}_${LIBNAME}/g"
 FILES="Makefile.am ast_link.in ast.news"
 
 cat > debian/patches/rename_library <<EOF
-Author: Ole Streicher <debian@liska.ath.cx>
+Author: Ole Streicher <olebole@debian.org>
 Last-Update: $(date +%Y-%m-%d)
 Description: "${LIBNAME}" is a quite short name for a library that is so 
  specific as this one. Therefore, and for consistency with the "pal" library, 
